@@ -15,12 +15,15 @@ MainWindow::MainWindow(QWidget *parent) :
     sdpyes = false;
     //cambackyes=false;
     ui->setupUi(this);
+    debugclicked = false;
     ui->labcust->hide();
     ui->custom1->hide();
     ui->outWind->hide();
     ui->sdpgen->hide();
     ui->stopsream->hide();
     ui->howtext->hide();
+    ui->filesinkname->hide();
+    ui->labfilenam->hide();
     ui->lenswidg->setStyleSheet("QWidget { background-color: rgb(60, 60, 100); }");
     ui->labcamwarn->setStyleSheet("QLabel {color : black;}");
     ui->okstream->setStyleSheet("QPushButton {background-color : black; color : white;}");
@@ -37,6 +40,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->scpframe->hide();
     ui->passwrd->setEchoMode(QLineEdit::Password);
     helpCounter=0;
+    ui->qcontrol->hide();
     applySettings();
 }
 
@@ -49,16 +53,27 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
     QString midbits;
     QString streamout;
     QString qbcam;
+    QString Jquality;
+    if(ui->tickqual->isChecked()){Jquality= "quality="+ui->qcontrol->text();}else{Jquality="";}   //necessary because the option kills quality, even if 100%
     if(video){
         if(backcamera){ qbcam = "0"; } else { qbcam = "1";}
-        if(outp==0){//VLC
-            midbits = "dsph264enc ! rtph264pay ! udpsink";
-        } else if (outp==1){ //Xout
-            midbits = "ffmpegcolorspace ! jpegenc ! tcpserversink";
-        } else if (outp==2){//webcam
-            midbits = "ffmpegcolorspace ! smokeenc ! udpsink";
+        if(outp!=3){ //filesink? no
+            if(outp==0){//VLC
+                midbits = "dsph264enc ! rtph264pay ! udpsink";
+            } else if (outp==1){ //Xout
+                midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
+            } else if (outp==2){//webcam
+                //midbits = "ffmpegcolorspace ! smokeenc ! udpsink";  using jpeg for quality preferences.
+                midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
+            } else if (outp==4){ //remote file
+                midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
+            }
+            streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" !"+midbits+" host="+host+" port="+port;
+        }
+        else if(outp==3){ //filesink
+            QString filelocation = ui->filesinkname->text();
+            streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! avimux ! filesink location=/home/user/MyDocs/.videos/"+filelocation+".avi";
         }
-        streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" !"+midbits+" host="+host+" port="+port;
     }
     else if (!video){
         streamout = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay ! udpsink host="+host+" port="+port;
@@ -78,7 +93,7 @@ void MainWindow::write2file(QString path, QString script){
     file.close();
     ui->outWind->append("Generated");
 
-    //make executable
+    //make executable-----------------doesnt work
     QStringList arguments;
     arguments << "-c" << "chmod a+x "+path;
     QProcess* exer = new QProcess(this);
@@ -93,6 +108,7 @@ void MainWindow::on_streambut_clicked()
     ui->camera1->setProperty("enabled", false);ui->custom1->setProperty("enabled",false);ui->outWind->setProperty("enabled", false); ui->debuginfo->setProperty("enabled",false);
     ui->sdpgen->setProperty("enabled", false); ui->scpbutton->setProperty("enabled", false);ui->vol->setProperty("enabled",false);ui->vidsink->setProperty("enabled",false);
     ui->stopsream->show(); ui->streambut->hide();
+    ui->tickqual->setProperty("enabled",false);ui->qcontrol->setProperty("enabled",false); ui->filesinkname->setProperty("enabled",false);
     //cameraselector
     if(ui->type1->currentIndex()==0 && ui->camera1->currentIndex()==0){
         cambackyes=true;
@@ -113,6 +129,7 @@ void MainWindow::writeSettings(){
     settings.setValue("address",ui->address1->text());settings.setValue("port",ui->port1->text());
     settings.setValue("type",ui->type1->currentIndex()); settings.setValue("camera",ui->camera1->currentIndex()); settings.setValue("size",ui->size1->currentIndex());
     settings.setValue("custom",ui->custom1->text()); settings.setValue("user",ui->usernam->text()); settings.setValue("password",ui->passwrd->text());settings.setValue("volume", ui->vol->text());
+    settings.setValue("quality",ui->qcontrol->text());
     settings.endGroup();
 }
 
@@ -122,7 +139,7 @@ void MainWindow::applySettings(){
     ui->address1->setText(settings.value("address").toString()); ui->port1->setText(settings.value("port").toString()); ui->type1->setCurrentIndex(settings.value("type").toInt());
     ui->size1->setCurrentIndex(settings.value("size").toInt()); ui->camera1->setCurrentIndex(settings.value("camera").toInt());
     ui->custom1->setText(settings.value("custom").toString());ui->usernam->setText(settings.value("user").toString()); ui->passwrd->setText(settings.value("password").toString());
-    ui->vol->setText(settings.value("volume").toString());
+    volumeR = settings.value("volume").toString(); ui->vol->setText(volumeR); ui->qcontrol->setText(settings.value("quality").toString());
     settings.endGroup();
     if(ui->type1->currentIndex()==1){
         on_type1_activated(1);
@@ -168,9 +185,14 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
         ui->custom1->hide();
         ui->labcust->hide();
         ui->vidsink->hide();
-        ui->labvidsink->hide();
+        ui->labvidsink->hide();ui->labvol->setText("Vol(0-9):");
+        ui->vol->setText(volumeR);
         ui->vol->show();
         ui->labvol->show();
+        ui->tickqual->hide();
+        ui->qcontrol->hide();
+        ui->labfilenam->hide();
+        ui->filesinkname->hide();
         videoyes = false;
     }
     else { //Video
@@ -182,6 +204,10 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
         ui->labvidsink->show();
         ui->vol->hide();
         ui->labvol->hide();
+        on_tickqual_toggled(ui->tickqual->checkState());
+        on_vidsink_activated(ui->vidsink->currentIndex());
+        on_camera1_activated(ui->camera1->currentIndex()); ///CORRECT?
+        on_size1_currentIndexChanged(ui->size1->currentText());
         videoyes = true;
     }
 }
@@ -219,6 +245,7 @@ void MainWindow::on_debuginfo_clicked()
 {
     ui->outWind->show();
     ui->sdpgen->show();
+    debugclicked = true;
 }
 
 QString MainWindow::getIP(){
@@ -231,8 +258,6 @@ QString MainWindow::getIP(){
     tmp = tmp.split(QRegExp("\\s+")).at(0); //removes spaces at end
     return tmp;
 
-    //list = tmp.split(QRegExp("\\s+"));//splits that string into a word list
-    //tmp = list.at(0)
 }
 
 void MainWindow::on_sdpgen_clicked()
@@ -255,7 +280,16 @@ void MainWindow::on_sdpgen_clicked()
     }
     else if(outpp==2) { //webcam
         currentFile = "/home/user/MyDocs/n900Webvideo.sh";
-        write2file(currentFile,"gst-launch-0.10 udpsrc port="+ui->port1->text()+" ! smokedec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0");  //webcam
+        //write2file(currentFile,"gst-launch-0.10 udpsrc port="+ui->port1->text()+" ! smokedec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0");  //webcam
+        //Using Jpeg for now, higer quality?
+        write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0"); //Xout
+    }
+    else if(outpp==3) {//filesink
+        ui->outWind->setText("Dont need to generate anything for a filesink.");
+    }
+    else if(outpp==4){//remote filesink
+        currentFile = "/home/user/MyDocs/n900FileSave.sh";
+        write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+" ! jpegdec ! ffenc_mpeg2video ! filesink location=/home/"+ui->usernam->text()+"/Desktop/"+ui->filesinkname->text()+".mpg");
     }
     sdpyes=true;
     ui->scpbutton->show();
@@ -268,11 +302,11 @@ void MainWindow::on_stopsream_clicked()
     terminator->start("killall gst-launch-0.10");
     terminator->waitForFinished();
     terminator->terminate();
-    //testing
+    //Turn off LED
     QString lstream = QString("dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:%1PatternWebcamActive%1").arg(QChar(0x22));
     ledterm->start(lstream);
     ledterm->waitForFinished();
-    //still testing
+    //
     ui->outWind->clear();
     ui->outWind->append("Stopped Steaming");
     ui->stopsream->hide();
@@ -281,6 +315,7 @@ void MainWindow::on_stopsream_clicked()
     ui->address1->setProperty("enabled", true);ui->port1->setProperty("enabled", true); ui->type1->setProperty("enabled", true); ui->size1->setProperty("enabled", true);
     ui->custom1->setProperty("enabled",true);ui->outWind->setProperty("enabled", true); ui->debuginfo->setProperty("enabled",true);ui->camera1->setProperty("enabled", true);
     ui->sdpgen->setProperty("enabled", true); ui->scpbutton->setProperty("enabled", true);ui->vol->setProperty("enabled",true);ui->vidsink->setProperty("enabled",true);
+    ui->tickqual->setProperty("enabled",true);ui->qcontrol->setProperty("enabled",true);ui->filesinkname->setProperty("enabled",true);
     //
     ledterm->terminate();
     proc.terminate();//doesn't do anything really
@@ -322,11 +357,41 @@ void MainWindow::on_scpsend_clicked()
 
 void MainWindow::on_vidsink_activated(int index)
 {
-    if(index==0){vidoutput = "VLC sdp";}
-else if(index==1){vidoutput = "Xscript";}
-else if(index==2){vidoutput="Webscript";}
-ui->sdpgen->setText("Generate "+vidoutput+" file");
-ui->scpbutton->setText("Send "+vidoutput+" to Linux PC");
+    if(index==3 || index==4){//File
+        ui->labfilenam->show();
+        ui->filesinkname->show();
+        ui->tickqual->show();
+        if(index==3){
+            ui->sdpgen->hide();
+            ui->scpbutton->hide();
+            ui->labfilenam->setText("     Filename (/home/user/MyDocs/.videos/):");
+            //Hide top row
+            ui->address1->hide(); ui->labAddr->hide(); ui->port1->hide(); ui->labPort->hide();
+        }
+        if(index==4) {
+            ui->sdpgen->show();
+            ui->labfilenam->setText("    Remote Filename:");
+            vidoutput="RemoteFilescript";
+            ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
+        }
+
+    } else if(index!=3 || index!=4){
+        ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
+        ui->labfilenam->hide();
+        ui->filesinkname->hide();
+        if(debugclicked){ui->sdpgen->show();}// stops it appearing when showdebug hasnt been clicked yet
+        if(index==0){
+            vidoutput = "VLC sdp";
+            ui->tickqual->hide();
+            ui->qcontrol->hide();
+        } else {
+            ui->tickqual->show();
+            if(index==1){vidoutput = "Xscript";}
+            if(index==2){vidoutput="Webscript";}
+        }
+    }
+    ui->sdpgen->setText("Generate "+vidoutput+" file");
+    ui->scpbutton->setText("Send "+vidoutput+" to Linux PC");
 }
 /*
 Add microphone support for use as main remote desktop mic.??
@@ -337,3 +402,14 @@ Ncurses version
 Stream to a file
 Stream to the web as watchdog
 */
+
+void MainWindow::on_tickqual_toggled(bool checked)
+{
+    if(checked==true){
+        ui->labvol->hide();
+        ui->qcontrol->show();
+    }
+    else if(checked==false) {
+        ui->qcontrol->hide();
+    }
+}
