@@ -32,8 +32,11 @@ private:
     bool sdpyes;
     QString vidoutput;
     QProcess proc;
+    QString volumeR;
+    bool debugclicked;
 
 private slots:
+    void on_tickqual_toggled(bool checked);
     void on_vidsink_activated(int index);
     void writeSettings(); void applySettings();
     void scpSender(QString user, QString pass, QString file);
